From 289948f53b5e0b00a656d60c08efbff0eb05fa90 Mon Sep 17 00:00:00 2001
From: dcc <dcc@163.com>
Date: Thu, 16 May 2024 15:37:05 +0800
Subject: [PATCH] 提款更改

---
 src/page/newUser/index.vue |  147 ++++++++++++++++++++++++++++++++++++++----------
 1 files changed, 116 insertions(+), 31 deletions(-)

diff --git a/src/page/newUser/index.vue b/src/page/newUser/index.vue
index 0289d1b..2e93ffc 100644
--- a/src/page/newUser/index.vue
+++ b/src/page/newUser/index.vue
@@ -5,7 +5,7 @@
         <div class="left_icon">
           <div>
             <img
-              src="../../assets/img/img_log_home.png"
+              src="../../assets/img/img_v3_02an_8a1a8e9f-0117-444b-8685-68793a3bd0ag.jpg"
               style="width: 40px; height: 40px; border-radius: 50px"
             />
           </div>
@@ -33,30 +33,30 @@
               <i @click="xy = !xy" class="iconfont xy">&#xe8c7;</i>
             </div>
             <div class="number-all">
-              <showHide :text="userInfo.totalAssets" :flg="xy" />
+              <showHide :text="asstesAll" :flg="xy" />
             </div>
           </van-col>
         </van-row>
         <van-row style="margin-top: 18px">
-          <div class="van-col van-col--8" style="margin-top: 10px">
-            <div class="content-title DINPro">{{ $t("美股總資產") }}(USD)</div>
-            <div>
-              <div class="DINPro" style="font-size: 18px">
-                <showHide :text="userInfo.usTotalAssets" :flg="xy" />
-              </div>
+          <div
+            class="van-col van-col--12"
+            style="margin-top: 10px"
+            v-for="item in listAsstes"
+            :key="item.accectType"
+          >
+            <div class="content-title DINPro">
+              {{ item.title3 }}
+              ({{ item.symbolCode }})
             </div>
-          </div>
-          <div class="van-col van-col--8" style="margin-top: 10px">
-            <div class="content-title">{{ $t("馬股總資產") }}(USD)</div>
             <div>
               <div class="DINPro" style="font-size: 18px">
-                <showHide :text="userInfo.masTotalAssets" :flg="xy" />
+                <showHide :text="item.availableBalance" :flg="xy" />
               </div>
             </div>
           </div>
         </van-row>
         <van-row style="margin-top: 16px">
-          <van-col span="8" style="display: flex; justify-content: center">
+          <van-col span="6" style="display: flex; justify-content: center">
             <van-button
               @click="$router.push('/recharge')"
               class="btn-two"
@@ -64,7 +64,7 @@
               >{{ $t("hj172") }}</van-button
             >
           </van-col>
-          <van-col span="8" style="display: flex; justify-content: center">
+          <van-col span="6" style="display: flex; justify-content: center">
             <van-button
               @click="$router.push('/RechargeSure')"
               class="btn-two"
@@ -73,7 +73,7 @@
             >
           </van-col>
           <!-- transferIndex -->
-          <van-col span="8" style="display: flex; justify-content: center">
+          <van-col span="6" style="display: flex; justify-content: center">
             <van-button
               @click="$router.push('/transferIndex')"
               class="btn-two"
@@ -81,10 +81,62 @@
               >{{ $t("hj245") }}</van-button
             >
           </van-col>
+          <van-col span="6" style="display: flex; justify-content: center">
+            <van-button
+              @click="leverShow = true"
+              class="btn-two"
+              type="default"
+            >
+              {{ $t("申请杠杠") }}
+            </van-button>
+          </van-col>
           <!-- <van-col span="6" style="display: flex; justify-content: center">
             <van-button class="btn-two" type="default">資金明細</van-button>
           </van-col> -->
         </van-row>
+        <van-dialog
+          v-model="leverShow"
+          :title="$t('申请杠杠')"
+          show-cancel-button
+          :cancelButtonText="$t('取消')"
+          :confirmButtonText="$t('确认')"
+          @confirm="confirmLever"
+        >
+          <van-radio-group v-model="radio">
+            <van-cell-group>
+              <van-cell title="2X" clickable @click="radio = '2'">
+                <template #right-icon>
+                  <van-radio name="2" />
+                </template>
+              </van-cell>
+              <van-cell title="5X" clickable @click="radio = '5'">
+                <template #right-icon>
+                  <van-radio name="5" />
+                </template>
+              </van-cell>
+              <van-cell title="10X" clickable @click="radio = '10'">
+                <template #right-icon>
+                  <van-radio name="10" />
+                </template>
+              </van-cell>
+              <van-cell title="20X" clickable @click="radio = '20'">
+                <template #right-icon>
+                  <van-radio name="20" />
+                </template>
+              </van-cell>
+              <van-cell title="50X" clickable @click="radio = '50'">
+                <template #right-icon>
+                  <van-radio name="50" />
+                </template>
+              </van-cell>
+              <van-cell title="100X" clickable @click="radio = '100'">
+                <template #right-icon>
+                  <van-radio name="100" />
+                </template>
+              </van-cell>
+            </van-cell-group>
+          </van-radio-group>
+        </van-dialog>
       </div>
       <div class="content-list-box">
         <div class="divider div-shrink"></div>
@@ -102,7 +154,7 @@
             :name="item.title"
           >
             <ul class="money">
-              <li>
+              <li style="text-align: left">
                 <div class="li-title">
                   {{ item.title1 }}({{ item.symbolCode }})
                 </div>
@@ -140,38 +192,53 @@
 import { isNull, pwdReg } from "@/utils/utils";
 import showHide from "@/components/showHide";
 import Vue from "vue";
+import { Notify } from "vant";
 export default {
   name: "newUser",
   components: { showHide },
   data() {
     return {
+      leverShow: false,
+      radio: "1",
       // 显示隐藏
       xy: true,
       listAsstes: [
         {
           title: this.$t("美股資產"),
+          title3: this.$t("美股總資產"),
           title1: this.$t("美股可用"),
           title2: this.$t("美股冻结"),
           accectType: "US",
           symbol: "$",
           symbolCode: "USD",
         },
+        {
+          title: this.$t("印股資產"),
+          title3: this.$t("印股總資產"),
+          title1: this.$t("印股可用"),
+          title2: this.$t("印股冻结"),
+          accectType: "IN",
+          symbol: "₹",
+          symbolCode: "IND",
+        },
         // {
         //   title: this.$t("印股資產"),
         //   title1: this.$t("印股可用"),
         //   title2: this.$t("印股冻结"),
         //   accectType: "IN",
         //   symbol: "RM",
         //   symbolCode: "MYR",
         // },
-        {
-          title: this.$t("馬股資產"),
-          title1: this.$t("馬股可用"),
-          title2: this.$t("馬股冻结"),
-          accectType: "MAS",
-          symbol: "RM",
-          symbolCode: "MYR",
-        },
+        // {
+        //   title: this.$t("港股资产"),
+        //   title3: this.$t("港股總資產"),
+        //   title1: this.$t("港股可用"),
+        //   title2: this.$t("港股冻结"),
+        //   accectType: "HK",
+        //   symbol: "HK$",
+        //   symbolCode: "HKD",
+        // },
       ],
       active: this.$t("美股資產"),
       name: "",
@@ -183,6 +250,7 @@
       userInfo: [],
       onlineService: "",
       moneyList: [],
+      asstesAll: "0.00",
     };
   },
   created() {
@@ -191,12 +259,25 @@
     this.getInfoSite();
   },
   methods: {
+    // 申请杠杠
+    async confirmLever() {
+      const res = await api.applyLever({ lever: this.radio });
+      if (res.status === 0) {
+        Notify({
+          type: "success",
+          message: this.$t("申请杠杠成功,请联系客服!"),
+        });
+      } else {
+        Notify({ type: "warning", message: res.msg });
+      }
+    },
     async getMoneyData() {
       let data = await api.getMoney();
       console.log(data);
       if (data.status === 0) {
         // 判断是否登录
         this.moneyList = data.data;
+        console.log(data.data)
         data.data.map((item) => {
           this.listAsstes.map((items) => {
             if (item.accectType === items.accectType) {
@@ -209,7 +290,9 @@
             }
           });
         });
-        console.log(this.listAsstes);
+
+        const arr = data.data.filter((item) => item.accectType === "ALL");
+        this.asstesAll = arr[0].totalMoneyUSD;
       }
     },
     tabsChange(e) {
@@ -301,7 +384,7 @@
     },
     async getUserInfo() {
       // 获取用户信息
-      let data = await api.getUserInfo();
+      let data = await api.getUserInfodata();
       if (data.status === 0) {
         // 判断是否登录
         this.$store.commit("dialogVisible", false);
@@ -486,6 +569,8 @@
       color: #2d2f3c;
     }
     .li-USDT {
+      min-width: 180px;
+      text-align: right;
       font-style: normal;
       font-weight: 500;
       font-size: 0.37333rem;
@@ -988,4 +1073,4 @@
 input[type="file"] {
   display: none !important;
 }
-</style>
\ No newline at end of file
+</style>
@@ -140,38 +192,53 @@
         // {
-        //   title: this.$t("印股資產"),
-        //   title1: this.$t("印股可用"),
-        //   title2: this.$t("印股冻结"),
-        //   accectType: "IN",
+        //   title: this.$t("馬股資產"),
+        //   title3: this.$t("馬股總資產"),
+        //   title1: this.$t("馬股可用"),
+        //   title2: this.$t("馬股冻结"),
+        //   accectType: "MAS",
         //   symbol: "RM",
         //   symbolCode: "MYR",

--
Gitblit v1.9.3